@@ -17,7 +17,7 @@
 #   License for the specific language governing permissions and limitations
 #   under the License.
 
-import os, unittest, json, tempfile, subprocess, csv, shutil, re
+import os, unittest, json, tempfile, subprocess, csv, shutil, re, base64
 
 from contextlib import contextmanager
 
@@ -405,5 +405,56 @@ class TestDXBuildApp(unittest.TestCase):
         with self.assertSubprocessFailure(stderr_regexp="Entry point file \\S+ has syntax errors"):
             run("dx-build-applet " + app_dir)
 
+
+class TestDXBuildReportHtml(unittest.TestCase):
+    def setUp(self):
+        self.temp_file_path = tempfile.mkdtemp()
+        self.gif_base64 = "R0lGODdhAQABAIAAAAQCBAAAACwAAAAAAQABAAACAkQBADs="
+        gif_file = open("{}/img.gif".format(self.temp_file_path), "w")
+        gif_file.write(base64.b64decode(self.gif_base64))
+        gif_file.close()
+        wiki_logo = "http://upload.wikimedia.org/wikipedia/en/thumb/8/80/Wikipedia-logo-v2.svg/200px-Wikipedia-logo-v2.svg.png"
+        html_file = open("{}/index.html".format(self.temp_file_path), "w")
+        html = "<html><body><img src='img.gif'/><img src='{}'/></body></html>".format(wiki_logo)
+        html_file.write(html)
+        html_file.close()
+    def tearDown(self):
+        shutil.rmtree(self.temp_file_path)
+
+    def test_local_file(self):
+        run(u"dx-build-report-html {d}/index.html --local {d}/out.html".format(d=self.temp_file_path))
+        out_path = "{}/out.html".format(self.temp_file_path)
+        self.assertTrue(os.path.exists(out_path))
+        f = open(out_path, "r")
+        html = f.read()
+        f.close()
+        self.assertTrue(re.search(self.gif_base64, html))
+        self.assertEquals(len(re.split("src=\"data:image", html)), 3)
+        self.assertEquals(len(re.split("<img", html)), 3)
+
+    def test_image_only(self):
+        run(u"dx-build-report-html {d}/img.gif --local {d}/gif.html".format(d=self.temp_file_path))
+        out_path = "{}/gif.html".format(self.temp_file_path)
+        self.assertTrue(os.path.exists(out_path))
+        f = open(out_path, "r")
+        html = f.read()
+        f.close()
+        self.assertTrue(html.startswith("<html><body><img src=\"data:"))
+
+    def test_remote_file(self):
+        report = json.loads(run(u"dx-build-report-html {d}/index.html --remote /html_report -w 47 -g 63".format(d=self.temp_file_path)))
+        fileId = report["fileIds"][0]
+        desc = json.loads(run(u"dx describe {record} --details --json".format(record=report["recordId"])))
+        self.assertEquals(desc["types"], [u"Report", u"HTMLReport"])
+        self.assertEquals(desc["name"], u"html_report")
+        self.assertEquals(desc["details"]["files"][0]["$dnanexus_link"], fileId)
+        self.assertEquals(desc["details"]["width"], "47")
+        self.assertEquals(desc["details"]["height"], "63")
+        desc = json.loads(run(u"dx describe {file} --details --json".format(file=fileId)))
+        self.assertTrue(desc["hidden"])
+        self.assertEquals(desc["name"], u"index.html")
+        run(u"dx rm {record} {file}".format(record=report["recordId"], file=fileId))
+
+
 if __name__ == '__main__':
     unittest.main()
